@@ -130,7 +130,10 @@ class ExcelTemplate(object):
                     time += restseconds
                     totdistance += restdistance
 
-        self.df['TimeStamp (sec)'] = unixnow+self.df['time']
+        try:
+            self.df['TimeStamp (sec)'] = unixnow+self.df['time']
+        except TypeError:
+            self.df['TimeStamp (sec)'] = self.df['time']
         self.df['power'] = 2.8*self.df['velo']**3
         mapping = {
             'time': ' ElapsedTime (sec)',
